==> oce_0.12.orig.tar.gz: oce-OCE-0.12/src/PDataStd/PDataStd_Integer.cxx <==
// Created on: 1997-04-09
// Created by: VAUTHIER Jean-Claude
// Copyright (c) 1997-1999 Matra Datavision
// Copyright (c) 1999-2012 OPEN CASCADE SAS
//
// The content of this file is subject to the Open CASCADE Technology Public
// License Version 6.5 (the "License"). You may not use the content of this file
// except in compliance with the License. Please obtain a copy of the License
// at http://www.opencascade.org and read it completely before using this file.
//
// The Initial Developer of the Original Code is Open CASCADE S.A.S., having its
// main offices at: 1, place des Freres Montgolfier, 78280 Guyancourt, France.
//
// The Original Code and all software distributed under the License is
// distributed on an "AS IS" basis, without warranty of any kind, and the
// Initial Developer hereby disclaims all such warranties, including without
// limitation, any warranties of merchantability, fitness for a particular
// purpose or non-infringement. Please see the License for the specific terms
// and conditions governing the rights and limitations under the License.



#include <PDataStd_Integer.ixx>


//=======================================================================
//function : PDataStd_Integer
//purpose  : 
//=======================================================================

PDataStd_Integer::PDataStd_Integer () {}


//=======================================================================
//function : PDataStd_Integer
//purpose  : 
//=======================================================================

PDataStd_Integer::PDataStd_Integer (const Standard_Integer V) : myValue (V) { }



//=======================================================================
//function : Set
//purpose  : 
//=======================================================================

void PDataStd_Integer::Set (const Standard_Integer V) 
{
  myValue = V;
}


//=======================================================================
//function : Get
//purpose  : 
//=======================================================================

Standard_Integer PDataStd_Integer::Get () const
{
  return myValue;
}

==> oce_0.15.orig.tar.gz: oce-OCE-0.15/src/PDataStd/PDataStd_Integer.cxx <==
// Created on: 1997-04-09
// Created by: VAUTHIER Jean-Claude
// Copyright (c) 1997-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and / or modify it
// under the terms of the GNU Lesser General Public version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <PDataStd_Integer.ixx>


//=======================================================================
//function : PDataStd_Integer
//purpose  : 
//=======================================================================

PDataStd_Integer::PDataStd_Integer () : myValue(0) {}


//=======================================================================
//function : PDataStd_Integer
//purpose  : 
//=======================================================================

PDataStd_Integer::PDataStd_Integer (const Standard_Integer V) : myValue (V) { }



//=======================================================================
//function : Set
//purpose  : 
//=======================================================================

void PDataStd_Integer::Set (const Standard_Integer V) 
{
  myValue = V;
}


//=======================================================================
//function : Get
//purpose  : 
//=======================================================================

Standard_Integer PDataStd_Integer::Get () const
{
  return myValue;
}
